Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.app/org.gvsig.view3d.app.common/src/main/resources-plugin/i18n/text.properties
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.app/org.gvsig.view3d.app.common/src/main/resources-plugin/i18n/text.properties	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.app/org.gvsig.view3d.app.common/src/main/resources-plugin/i18n/text.properties	(revision 760)
@@ -1,4 +1,5 @@
 3D = 3D
+absolute=Absoluto
 anaglyph_mode = Modo anaglifo
 auto_synchronize_layers=Sincronizado autom\u00E1tico de capas
 auto_synchronize_view_ports=Sincronizado autom\u00E1tico de enfoques
@@ -6,23 +7,30 @@
 close_and_re-create_3D_views_to_active_anagliph_mode = Cierre y vuelva a crear las vistas 3D para activar el modo anaglifo.
 close_and_re-create_3D_views_to_desactive_anagliph_mode = Cierre y vuelva a crear las vistas 3D para desactivar el modo anaglifo.
 components= Componentes
+constant_height=Altura constante
+constant_height_has_to_be_a_number=El campo "Altura constante" debe ser num\u00e9rico
+clamp_to_ground=Fijada al terreno
 elevation= Elevaci\u00F3n
+elevation_mode=Modo de elevaci\u00f3n
 elevation_field= Campo elevaci\u00F3n
 elevation_units = Unidades de elevaci�n
 flat_vertical_exaggeration= Exageraci\u00F3n vertical visor plano
 flat_view_3d= Vista 3D plana
 full_screen_mode_view_3d= Modo pantalla completa
+height_field=Campo altura
 invalid_loader_parameters = Par�metros del modo de carga
+invalid_constant_height_value = Altura constante 
 level_details= Niveles de detalle
 load_mode= Modo de carga
 maximum_detail_level= M�ximo nivel de detalle
-maximum_detail_level_has_to_be_a_number = M�ximo nivel de detalle debe ser num�rico
+maximum_detail_level_has_to_be_a_number = El campo "M�ximo nivel de detalle" debe ser num\u00e9rico
 minimum_detail_level= M�nimo nivel de detalle
-minimum_detail_level_has_to_be_a_number = M�nimo nivel de detalle debe ser num�rico
+minimum_detail_level_has_to_be_a_number = El campo "M�nimo nivel de detalle" debe ser num\u00e9rico
 nodata_value= Valor NoData
-nodata_value_has_to_be_a_number = Valor NoData debe ser num�rico
+nodata_value_has_to_be_a_number = El campo "Valor NoData" debe ser num\u00e9rico
 raster_image= Imagen raster
 rasterized_vectorial= Vectorial rasterizada
+relative_to_ground=Relativo al terreno
 show_blue_marble_layer= Mostrar capa Blue Marble
 show_atmosphere= Mostrar atm\u00F3sfera
 show_default_elevation= Mostrar elevaci\u00F3n por defecto
@@ -37,7 +45,11 @@
 spherical_view_3d=  Vista 3D esf\u00E9rica
 tile_configuration= Configuraci\u00F3n de tiles
 tile_size = Tama�o de tesela
-tile_size_has_to_be_a_number = Tama�o de tesela debe ser num�rico
+tile_size_has_to_be_a_number = El campo "Tama�o de tesela" debe ser num\u00e9rico
+vector_extrusion=Extrusi\u00f3n
+vector_load_mode=Vectorial
+vertical_exaggeration=Exageraci\u00f3n vertical
+vertical_exaggeration_has_to_be_a_number=El campo "Exageraci\u00f3n vertical" debe ser num\u00e9rico
 view_3d = Visor 3D
 view_port_animation= Animaci\u00F3n sincronizaci\u00F3n enfoques
 zero_level_resolution= Resoluci\u00F3n nivel cero
\ No newline at end of file
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.app/org.gvsig.view3d.app.common/src/main/resources-plugin/i18n/text_en.properties
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.app/org.gvsig.view3d.app.common/src/main/resources-plugin/i18n/text_en.properties	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.app/org.gvsig.view3d.app.common/src/main/resources-plugin/i18n/text_en.properties	(revision 760)
@@ -1,4 +1,5 @@
 3D= 3D
+absolute=Absolute
 anaglyph_mode = Anaglyph mode
 auto_synchronize_layers= Auto synchronize layers
 auto_synchronize_view_ports=Auto synchronize viewport
@@ -6,23 +7,29 @@
 close_and_re-create_3D_views_to_active_anagliph_mode = Close and re-create 3D views to activate anagliph mode.
 close_and_re-create_3D_views_to_desactive_anagliph_mode = Close and re-create 3D views to desactivate anagliph mode.
 components= Components
+constant_height=Constant height
+constant_height_has_to_be_a_number=The field "Constant height" has to be numeric
+clamp_to_ground=Clamp to ground
 elevation= Elevation
+elevation_mode=Elevation mode
 elevation_field= Elevation field
 elevation_units = Elevation units
 flat_vertical_exaggeration= Flat vertical exaggeration
 flat_view_3d= Flat 3D view
 full_screen_mode_view_3d= Full screen mode
+height_field=Height field
 invalid_loader_parameters = Invalid loader parameters
 level_details= Level of details
 load_mode= Loading mode
 maximum_detail_level= Maximum detail level
-maximum_detail_level_has_to_be_a_number = Maximum detail level has to be numeric
+maximum_detail_level_has_to_be_a_number = The field "Maximum detail level" has to be numeric
 minimum_detail_level= Minimum detail level
-minimum_detail_level_has_to_be_a_number = Minimum detail level has to be numeric
+minimum_detail_level_has_to_be_a_number = The field "Minimum detail level" has to be numeric
 nodata_value= NoData value
-nodata_value_has_to_be_a_number = NoData value has to be numeric
+nodata_value_has_to_be_a_number = The field "NoData value" has to be numeric
 raster_image= Raster image
-rasterized_vectorial= Rasterized vectorial
+rasterized_vectorial= Rasterized vector
+relative_to_ground=Relative to ground
 show_atmosphere= Show atmosphere
 show_blue_marble_layer= Show Blue Marble layer
 show_default_elevation= Show default elevation
@@ -38,6 +45,10 @@
 tile_configuration= Tile configuration
 tile_size = Tile size
 tile_size_has_to_be_a_number = Tile size has to be numeric
+vector_extrusion=Extrusion
+vector_load_mode=Vector
+vertical_exaggeration=Vertical exaggeration
+vertical_exaggeration_has_to_be_a_number=The field "Vertical exaggeration" has to be number
 view_3d= 3D View
 view_port_animation= View port animation
 zero_level_resolution= Zero level resolution
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/ElevationModeComboBoxRenderer.java
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/ElevationModeComboBoxRenderer.java	(revision 0)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/ElevationModeComboBoxRenderer.java	(revision 760)
@@ -0,0 +1,30 @@
+package org.gvsig.view3d.vector.swing.impl;
+
+import java.awt.Component;
+
+import javax.swing.JLabel;
+import javax.swing.JList;
+import javax.swing.ListCellRenderer;
+
+import org.gvsig.tools.ToolsLocator;
+import org.gvsig.tools.i18n.I18nManager;
+import org.gvsig.view3d.vector.lib.api.VectorElevationMode;
+
+public class ElevationModeComboBoxRenderer extends JLabel implements ListCellRenderer{
+
+    @Override
+    public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected,
+        boolean cellHasFocus) {
+        
+        VectorElevationMode mode = (VectorElevationMode) value;
+        if(mode != null) {
+            I18nManager i18nManager = ToolsLocator.getI18nManager();
+            this.setText(i18nManager.getTranslation(mode.name().toLowerCase()));
+        } else {
+            this.setText("");
+        }
+        
+        return this;
+    }
+
+}
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersController.java
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersController.java	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersController.java	(revision 760)
@@ -1,9 +1,23 @@
 package org.gvsig.view3d.vector.swing.impl;
 
+import java.util.Arrays;
+import java.util.List;
+
 import javax.swing.JComponent;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import org.gvsig.tools.ToolsLocator;
+import org.gvsig.tools.dataTypes.CoercionException;
+import org.gvsig.tools.dataTypes.DataTypes;
+import org.gvsig.tools.dataTypes.DataTypesManager;
+import org.gvsig.tools.dataTypes.DataTypesManager.Coercion;
+import org.gvsig.tools.i18n.I18nManager;
 import org.gvsig.view3d.lib.api.loader.LoaderParameters;
 import org.gvsig.view3d.swing.api.exception.InvalidLoaderParametersException;
+import org.gvsig.view3d.vector.lib.api.VectorElevationMode;
+import org.gvsig.view3d.vector.lib.api.VectorLoaderParameters;
 import org.gvsig.view3d.vector.swing.api.JVectorLoaderParameters;
 
 /**
@@ -15,10 +29,78 @@
 
     private static final long serialVersionUID = -4115765106906551132L;
 
+    private static final Logger LOG = LoggerFactory.getLogger(JVectorLoaderParametersController.class);
+
+    private JColorChooserButton colorChooserButton;
+
+    private VectorLoaderParameters parameters;
+
+    public JVectorLoaderParametersController(VectorLoaderParameters parameters) {
+        super();
+        this.parameters = parameters;
+
+        translate();
+        initComponents();
+    }
+
+    private void translate() {
+        I18nManager i18nManager = ToolsLocator.getI18nManager();
+        this.elevationModeText.setText(i18nManager.getTranslation(this.elevationModeText.getText()));
+        this.defaultColorText.setText(i18nManager.getTranslation(this.defaultColorText.getText()));
+        this.constantHeightText.setText(i18nManager.getTranslation(this.constantHeightText.getText()));
+    }
+
+    @SuppressWarnings("unchecked")
+    private void initComponents() {
+
+        List<VectorElevationMode> elevationModes = Arrays.asList(VectorElevationMode.values());
+
+        // Elevation mode
+        this.elevationMode.setRenderer(new ElevationModeComboBoxRenderer());
+        for (VectorElevationMode mode : elevationModes) {
+            this.elevationMode.addItem(mode);
+        }
+        
+        if(parameters.getVectorElevationMode() != null) {
+            this.elevationMode.setSelectedItem(parameters.getVectorElevationMode());
+        }
+
+        // Default Color
+        this.colorChooserButton = new JColorChooserButton(parameters.getDefaultColor());
+        this.defaultColorPanel.add(colorChooserButton);
+
+        // Constant height
+        try {
+            DataTypesManager dataTypesManager = ToolsLocator.getDataTypesManager();
+            Coercion stringCoercion = dataTypesManager.getCoercion(DataTypes.STRING);
+            this.constantHeight.setText((String) stringCoercion.coerce(parameters.getConstantHeight()));
+        } catch (CoercionException e) {
+            LOG.error(
+                String.format("Can not parse constant this height value %d to string", parameters.getConstantHeight()),
+                e);
+            this.constantHeight.setText("");
+        }
+    }
+
     @Override
     public LoaderParameters getLoaderParameters() throws InvalidLoaderParametersException {
-        // TODO Auto-generated method stub
-        return null;
+
+        this.parameters.setVectorElevationMode((VectorElevationMode) this.elevationMode.getSelectedItem());
+        this.parameters.setDefaultColor(this.colorChooserButton.getSelectedColor());
+
+        try {
+            DataTypesManager dataTypesManager = ToolsLocator.getDataTypesManager();
+            Coercion doubleCoercion = dataTypesManager.getCoercion(DataTypes.DOUBLE);
+            this.parameters.setConstantHeight((double) doubleCoercion.coerce(this.constantHeight.getText()));
+        } catch (CoercionException e) {
+            LOG.error(
+                String.format("Can not parse constant this height value %s to double", this.constantHeight.getText()),
+                e);
+            throw new InvalidLoaderParametersException("Invalid constant height value",
+                "constant_height_has_to_be_a_number", e);
+        }
+
+        return this.parameters;
     }
 
     @Override
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersController.java
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersController.java	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersController.java	(revision 760)
@@ -1,19 +1,175 @@
 package org.gvsig.view3d.vector.swing.impl;
 
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.util.Arrays;
+import java.util.List;
+
 import javax.swing.JComponent;
 
+import org.apache.commons.lang3.StringUtils;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import org.gvsig.fmap.dal.exception.DataException;
+import org.gvsig.fmap.dal.feature.FeatureAttributeDescriptor;
+import org.gvsig.fmap.dal.feature.FeatureStore;
+import org.gvsig.fmap.dal.feature.FeatureType;
+import org.gvsig.fmap.mapcontext.layers.FLayer;
+import org.gvsig.fmap.mapcontext.layers.vectorial.FLyrVect;
+import org.gvsig.tools.ToolsLocator;
+import org.gvsig.tools.dataTypes.CoercionException;
+import org.gvsig.tools.dataTypes.DataTypes;
+import org.gvsig.tools.dataTypes.DataTypesManager;
+import org.gvsig.tools.dataTypes.DataTypesManager.Coercion;
+import org.gvsig.tools.i18n.I18nManager;
 import org.gvsig.view3d.lib.api.loader.LoaderParameters;
 import org.gvsig.view3d.swing.api.exception.InvalidLoaderParametersException;
+import org.gvsig.view3d.vector.lib.api.VectorElevationMode;
+import org.gvsig.view3d.vector.lib.api.VectorExtrusionLoaderParameters;
 import org.gvsig.view3d.vector.swing.api.JVectorExtrusionLoaderParameters;
 
-public class JVectorExtrusionLoaderParametersController extends JVectorExtrusionLoaderParametersView implements JVectorExtrusionLoaderParameters {
+public class JVectorExtrusionLoaderParametersController extends JVectorExtrusionLoaderParametersView
+    implements JVectorExtrusionLoaderParameters {
 
     private static final long serialVersionUID = 26999444514713602L;
 
+    private static final Logger LOG = LoggerFactory.getLogger(JVectorExtrusionLoaderParametersController.class);
+
+    private JColorChooserButton colorChooserButton;
+
+    private VectorExtrusionLoaderParameters parameters;
+
+    public JVectorExtrusionLoaderParametersController(VectorExtrusionLoaderParameters parameters) {
+        super();
+
+        this.parameters = parameters;
+        translate();
+        initComponents();
+    }
+
+    private void translate() {
+        I18nManager i18nManager = ToolsLocator.getI18nManager();
+        this.elevationModeText.setText(i18nManager.getTranslation(this.elevationModeText.getText()));
+        this.defaultColorText.setText(i18nManager.getTranslation(this.defaultColorText.getText()));
+        this.constantHeightText.setText(i18nManager.getTranslation(this.constantHeightText.getText()));
+        this.heightFieldText.setText(i18nManager.getTranslation(this.heightFieldText.getText()));
+        this.verticalExaggerationText.setText(i18nManager.getTranslation(this.verticalExaggerationText.getText()));
+    }
+
+    @SuppressWarnings("unchecked")
+    private void initComponents() {
+
+        List<VectorElevationMode> elevationModes = Arrays.asList(VectorElevationMode.values());
+
+        // Elevation mode
+        this.elevationMode.setRenderer(new ElevationModeComboBoxRenderer());
+        for (VectorElevationMode mode : elevationModes) {
+            this.elevationMode.addItem(mode);
+        }
+        if(parameters.getVectorElevationMode() != null) {
+            this.elevationMode.setSelectedItem(parameters.getVectorElevationMode());
+        }
+
+        // Default Color
+        this.colorChooserButton = new JColorChooserButton(parameters.getDefaultColor());
+        this.defaultColorPanel.add(colorChooserButton);
+
+        DataTypesManager dataTypesManager = ToolsLocator.getDataTypesManager();
+        Coercion stringCoercion = dataTypesManager.getCoercion(DataTypes.STRING);
+        // Constant height
+        try {
+            this.constantHeight.setText((String) stringCoercion.coerce(parameters.getConstantHeight()));
+        } catch (CoercionException e) {
+            LOG.error(String.format("Can not parse constant height value %d to string", parameters.getConstantHeight()),
+                e);
+            this.constantHeight.setText("");
+        }
+
+        // Vertical exaggeration
+        try {
+            String verticalExaggeration = (String) stringCoercion.coerce(parameters.getVerticalExaggeration());
+            if(StringUtils.isBlank(verticalExaggeration)) {
+                this.verticalExaggeration.setText("1.0");
+            } else {
+                this.verticalExaggeration.setText(verticalExaggeration);
+            }
+        } catch (CoercionException e) {
+            LOG.error(String.format("Can not parse vertical exaggeration value %d to string",
+                parameters.getVerticalExaggeration()), e);
+            this.verticalExaggeration.setText("");
+        }
+
+        // Height field
+        heightField.addItem("");
+        
+        FLayer layer = this.parameters.getLayer();
+        if (layer instanceof FLyrVect) {
+
+            FLyrVect vectorLayer = (FLyrVect) layer;
+            FeatureStore featureStore = vectorLayer.getFeatureStore();
+            FeatureType featureType = null;
+            try {
+                featureType = featureStore.getDefaultFeatureType();
+            } catch (DataException e) {
+                LOG.error(String.format("Can not get feature type of %1s", vectorLayer.getName()), e);
+                return;
+            }
+            FeatureAttributeDescriptor[] attributeDescriptors = featureType.getAttributeDescriptors();
+            for (FeatureAttributeDescriptor attDesc : attributeDescriptors) {
+                heightField.addItem(attDesc.getName());
+            }
+        }
+        
+        // Initialize change listeners
+        this.heightField.addActionListener(new ActionListener() {
+            
+            @Override
+            public void actionPerformed(ActionEvent e) {
+                String selectedValue = (String) heightField.getSelectedItem();
+                if(StringUtils.isBlank(selectedValue)) {
+                    constantHeightText.setEnabled(true);
+                    constantHeight.setEnabled(true);
+                } else {
+                    constantHeightText.setEnabled(false);
+                    constantHeight.setEnabled(false);
+                }
+            }
+        });
+    }
+
     @Override
     public LoaderParameters getLoaderParameters() throws InvalidLoaderParametersException {
-        // TODO Auto-generated method stub
-        return null;
+        
+        DataTypesManager dataTypesManager = ToolsLocator.getDataTypesManager();
+        Coercion doubleCoercion = dataTypesManager.getCoercion(DataTypes.DOUBLE);
+
+        this.parameters.setVectorElevationMode((VectorElevationMode) this.elevationMode.getSelectedItem());
+        this.parameters.setDefaultColor(this.colorChooserButton.getSelectedColor());
+        
+        if(StringUtils.isNotBlank((String) this.heightField.getSelectedItem())) {
+            this.parameters.setHeightField((String) this.heightField.getSelectedItem());
+        } else {
+            try {
+                this.parameters.setConstantHeight((double) doubleCoercion.coerce(this.constantHeight.getText()));
+            } catch (CoercionException e) {
+                LOG.error(String.format("Can not parse constant height value %s to double", this.constantHeight.getText()),
+                    e);
+                throw new InvalidLoaderParametersException("Invalid constant height value", "constant_height_has_to_be_a_number",
+                    e);
+            }
+        }
+        
+        try {
+            this.parameters.setVerticalExaggeration((double) doubleCoercion.coerce(this.verticalExaggeration.getText()));
+        } catch (CoercionException e) {
+            LOG.error(String.format("Can not parse vertical exaggeration value %s to double",
+                this.verticalExaggeration.getText()), e);
+            throw new InvalidLoaderParametersException("Invalid vertical exaggeration value",
+                "vertical_exaggeration_has_to_be_a_number", e);
+        }
+
+        return this.parameters;
     }
 
     @Override
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersFactory.java
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersFactory.java	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersFactory.java	(revision 760)
@@ -8,6 +8,7 @@
 import org.gvsig.view3d.swing.api.loader.JLoaderParameters;
 import org.gvsig.view3d.swing.api.loader.JLoaderParametersFactory;
 import org.gvsig.view3d.vector.lib.api.VectorExtrusionLoaderParameters;
+import org.gvsig.view3d.vector.lib.api.VectorLoaderParameters;
 
 /**
  * 
@@ -25,25 +26,29 @@
     }
 
     @Override
-    public JLoaderParameters createJLoaderParameters(
-        LoaderParameters parameters) throws JLoaderParameterCreationException {
-        return new JVectorLoaderParametersController();
+    public JLoaderParameters createJLoaderParameters(LoaderParameters parameters)
+        throws JLoaderParameterCreationException {
+
+        if (parameters instanceof VectorLoaderParameters) {
+            return new JVectorLoaderParametersController((VectorLoaderParameters) parameters);
+        }
+        throw new JLoaderParameterCreationException("Vector");
     }
 
     @Override
     public String getDisplayName() {
         I18nManager i18nManager = ToolsLocator.getI18nManager();
-        return i18nManager.getTranslation("vector_extrusion");
+        return i18nManager.getTranslation("vector_load_mode");
     }
 
     @Override
     public String getName() {
-        return VectorExtrusionLoaderParameters.NAME;
+        return VectorLoaderParameters.NAME;
     }
 
     @Override
     public int getPriority() {
-        return 40;
+        return 30;
     }
 
 }
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersFactory.java
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersFactory.java	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersFactory.java	(revision 760)
@@ -7,6 +7,7 @@
 import org.gvsig.view3d.swing.api.exception.JLoaderParameterCreationException;
 import org.gvsig.view3d.swing.api.loader.JLoaderParameters;
 import org.gvsig.view3d.swing.api.loader.JLoaderParametersFactory;
+import org.gvsig.view3d.vector.lib.api.VectorExtrusionLoaderParameters;
 import org.gvsig.view3d.vector.lib.api.VectorLoaderParameters;
 
 /**
@@ -27,23 +28,26 @@
     @Override
     public JLoaderParameters createJLoaderParameters(LoaderParameters parameters)
         throws JLoaderParameterCreationException {
-        return new JVectorExtrusionLoaderParametersController();
+        if (parameters instanceof VectorExtrusionLoaderParameters) {
+            return new JVectorExtrusionLoaderParametersController((VectorExtrusionLoaderParameters) parameters);
+        }
+        throw new JLoaderParameterCreationException("Vector extrusion");
     }
 
     @Override
     public String getDisplayName() {
         I18nManager i18nManager = ToolsLocator.getI18nManager();
-        return i18nManager.getTranslation("vector");
+        return i18nManager.getTranslation("vector_extrusion");
     }
 
     @Override
     public String getName() {
-        return VectorLoaderParameters.NAME;
+        return VectorExtrusionLoaderParameters.NAME;
     }
 
     @Override
     public int getPriority() {
-        return 30;
+        return 40;
     }
 
 }
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersView.xml
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersView.xml	(revision 0)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersView.xml	(revision 760)
@@ -0,0 +1,458 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<object classname="com.jeta.forms.store.memento.FormPackage">
+ <at name="fileversion">
+  <object classname="com.jeta.forms.store.memento.FormsVersion2">
+   <at name="major">2</at>
+   <at name="minor">0</at>
+   <at name="sub">0</at>
+  </object>
+ </at>
+ <at name="form">
+  <object classname="com.jeta.forms.store.memento.FormMemento">
+   <super classname="com.jeta.forms.store.memento.ComponentMemento">
+    <at name="cellconstraints">
+     <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+      <at name="column">1</at>
+      <at name="row">1</at>
+      <at name="colspan">1</at>
+      <at name="rowspan">1</at>
+      <at name="halign">default</at>
+      <at name="valign">default</at>
+      <at name="insets" object="insets">0,0,0,0</at>
+     </object>
+    </at>
+    <at name="componentclass">com.jeta.forms.gui.form.FormComponent</at>
+   </super>
+   <at name="id">/home/lmarques/projects/externals/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersView.xml</at>
+   <at name="rowspecs">CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE</at>
+   <at name="colspecs">FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:GROW(1.0)</at>
+   <at name="components">
+    <object classname="java.util.LinkedList">
+     <item >
+      <at name="value">
+       <object classname="com.jeta.forms.store.memento.BeanMemento">
+        <super classname="com.jeta.forms.store.memento.ComponentMemento">
+         <at name="cellconstraints">
+          <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+           <at name="column">1</at>
+           <at name="row">2</at>
+           <at name="colspan">1</at>
+           <at name="rowspan">1</at>
+           <at name="halign">default</at>
+           <at name="valign">default</at>
+           <at name="insets" object="insets">0,0,0,0</at>
+          </object>
+         </at>
+         <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
+        </super>
+        <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
+        <at name="beanclass">com.jeta.forms.components.label.JETALabel</at>
+        <at name="beanproperties">
+         <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+          <at name="classname">com.jeta.forms.components.label.JETALabel</at>
+          <at name="properties">
+           <object classname="com.jeta.forms.store.support.PropertyMap">
+            <at name="border">
+             <object classname="com.jeta.forms.store.properties.CompoundBorderProperty">
+              <super classname="com.jeta.forms.store.properties.BorderProperty">
+               <at name="name">border</at>
+              </super>
+              <at name="borders">
+               <object classname="java.util.LinkedList">
+                <item >
+                 <at name="value">
+                  <object classname="com.jeta.forms.store.properties.DefaultBorderProperty">
+                   <super classname="com.jeta.forms.store.properties.BorderProperty">
+                    <at name="name">border</at>
+                   </super>
+                  </object>
+                 </at>
+                </item>
+               </object>
+              </at>
+             </object>
+            </at>
+            <at name="name">elevationModeText</at>
+            <at name="width">90</at>
+            <at name="text">elevation_mode</at>
+            <at name="fill">
+             <object classname="com.jeta.forms.store.properties.effects.PaintProperty">
+              <at name="name">fill</at>
+             </object>
+            </at>
+            <at name="height">14</at>
+           </object>
+          </at>
+         </object>
+        </at>
+       </object>
+      </at>
+     </item>
+     <item >
+      <at name="value">
+       <object classname="com.jeta.forms.store.memento.BeanMemento">
+        <super classname="com.jeta.forms.store.memento.ComponentMemento">
+         <at name="cellconstraints">
+          <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+           <at name="column">1</at>
+           <at name="row">4</at>
+           <at name="colspan">1</at>
+           <at name="rowspan">1</at>
+           <at name="halign">default</at>
+           <at name="valign">default</at>
+           <at name="insets" object="insets">0,0,0,0</at>
+          </object>
+         </at>
+         <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
+        </super>
+        <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
+        <at name="beanclass">com.jeta.forms.components.label.JETALabel</at>
+        <at name="beanproperties">
+         <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+          <at name="classname">com.jeta.forms.components.label.JETALabel</at>
+          <at name="properties">
+           <object classname="com.jeta.forms.store.support.PropertyMap">
+            <at name="border">
+             <object classname="com.jeta.forms.store.properties.CompoundBorderProperty">
+              <super classname="com.jeta.forms.store.properties.BorderProperty">
+               <at name="name">border</at>
+              </super>
+              <at name="borders">
+               <object classname="java.util.LinkedList">
+                <item >
+                 <at name="value">
+                  <object classname="com.jeta.forms.store.properties.DefaultBorderProperty">
+                   <super classname="com.jeta.forms.store.properties.BorderProperty">
+                    <at name="name">border</at>
+                   </super>
+                  </object>
+                 </at>
+                </item>
+               </object>
+              </at>
+             </object>
+            </at>
+            <at name="name">defaultColorText</at>
+            <at name="width">90</at>
+            <at name="text">default_color</at>
+            <at name="fill">
+             <object classname="com.jeta.forms.store.properties.effects.PaintProperty">
+              <at name="name">fill</at>
+             </object>
+            </at>
+            <at name="height">14</at>
+           </object>
+          </at>
+         </object>
+        </at>
+       </object>
+      </at>
+     </item>
+     <item >
+      <at name="value">
+       <object classname="com.jeta.forms.store.memento.BeanMemento">
+        <super classname="com.jeta.forms.store.memento.ComponentMemento">
+         <at name="cellconstraints">
+          <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+           <at name="column">1</at>
+           <at name="row">6</at>
+           <at name="colspan">1</at>
+           <at name="rowspan">1</at>
+           <at name="halign">default</at>
+           <at name="valign">default</at>
+           <at name="insets" object="insets">0,0,0,0</at>
+          </object>
+         </at>
+         <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
+        </super>
+        <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
+        <at name="beanclass">com.jeta.forms.components.label.JETALabel</at>
+        <at name="beanproperties">
+         <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+          <at name="classname">com.jeta.forms.components.label.JETALabel</at>
+          <at name="properties">
+           <object classname="com.jeta.forms.store.support.PropertyMap">
+            <at name="border">
+             <object classname="com.jeta.forms.store.properties.CompoundBorderProperty">
+              <super classname="com.jeta.forms.store.properties.BorderProperty">
+               <at name="name">border</at>
+              </super>
+              <at name="borders">
+               <object classname="java.util.LinkedList">
+                <item >
+                 <at name="value">
+                  <object classname="com.jeta.forms.store.properties.DefaultBorderProperty">
+                   <super classname="com.jeta.forms.store.properties.BorderProperty">
+                    <at name="name">border</at>
+                   </super>
+                  </object>
+                 </at>
+                </item>
+               </object>
+              </at>
+             </object>
+            </at>
+            <at name="name">constantHeightText</at>
+            <at name="width">90</at>
+            <at name="text">constant_height</at>
+            <at name="fill">
+             <object classname="com.jeta.forms.store.properties.effects.PaintProperty">
+              <at name="name">fill</at>
+             </object>
+            </at>
+            <at name="height">14</at>
+           </object>
+          </at>
+         </object>
+        </at>
+       </object>
+      </at>
+     </item>
+     <item >
+      <at name="value">
+       <object classname="com.jeta.forms.store.memento.BeanMemento">
+        <super classname="com.jeta.forms.store.memento.ComponentMemento">
+         <at name="cellconstraints">
+          <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+           <at name="column">3</at>
+           <at name="row">2</at>
+           <at name="colspan">2</at>
+           <at name="rowspan">1</at>
+           <at name="halign">default</at>
+           <at name="valign">default</at>
+           <at name="insets" object="insets">0,0,0,0</at>
+          </object>
+         </at>
+         <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
+        </super>
+        <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
+        <at name="beanclass">javax.swing.JComboBox</at>
+        <at name="beanproperties">
+         <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+          <at name="classname">javax.swing.JComboBox</at>
+          <at name="properties">
+           <object classname="com.jeta.forms.store.support.PropertyMap">
+            <at name="border">
+             <object classname="com.jeta.forms.store.properties.CompoundBorderProperty">
+              <super classname="com.jeta.forms.store.properties.BorderProperty">
+               <at name="name">border</at>
+              </super>
+              <at name="borders">
+               <object classname="java.util.LinkedList">
+                <item >
+                 <at name="value">
+                  <object classname="com.jeta.forms.store.properties.DefaultBorderProperty">
+                   <super classname="com.jeta.forms.store.properties.BorderProperty">
+                    <at name="name">border</at>
+                   </super>
+                  </object>
+                 </at>
+                </item>
+               </object>
+              </at>
+             </object>
+            </at>
+            <at name="name">elevationMode</at>
+            <at name="width">814</at>
+            <at name="items">
+             <object classname="com.jeta.forms.store.properties.ItemsProperty">
+              <at name="name">items</at>
+             </object>
+            </at>
+            <at name="height">20</at>
+           </object>
+          </at>
+         </object>
+        </at>
+       </object>
+      </at>
+     </item>
+     <item >
+      <at name="value">
+       <object classname="com.jeta.forms.store.memento.BeanMemento">
+        <super classname="com.jeta.forms.store.memento.ComponentMemento">
+         <at name="cellconstraints">
+          <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+           <at name="column">3</at>
+           <at name="row">6</at>
+           <at name="colspan">2</at>
+           <at name="rowspan">1</at>
+           <at name="halign">default</at>
+           <at name="valign">default</at>
+           <at name="insets" object="insets">0,0,0,0</at>
+          </object>
+         </at>
+         <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
+        </super>
+        <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
+        <at name="beanclass">javax.swing.JTextField</at>
+        <at name="beanproperties">
+         <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+          <at name="classname">javax.swing.JTextField</at>
+          <at name="properties">
+           <object classname="com.jeta.forms.store.support.PropertyMap">
+            <at name="border">
+             <object classname="com.jeta.forms.store.properties.CompoundBorderProperty">
+              <super classname="com.jeta.forms.store.properties.BorderProperty">
+               <at name="name">border</at>
+              </super>
+              <at name="borders">
+               <object classname="java.util.LinkedList">
+                <item >
+                 <at name="value">
+                  <object classname="com.jeta.forms.store.properties.DefaultBorderProperty">
+                   <super classname="com.jeta.forms.store.properties.BorderProperty">
+                    <at name="name">border</at>
+                   </super>
+                  </object>
+                 </at>
+                </item>
+               </object>
+              </at>
+             </object>
+            </at>
+            <at name="name">constantHeight</at>
+            <at name="width">814</at>
+            <at name="height">20</at>
+           </object>
+          </at>
+         </object>
+        </at>
+       </object>
+      </at>
+     </item>
+     <item >
+      <at name="value">
+       <object classname="com.jeta.forms.store.memento.BeanMemento">
+        <super classname="com.jeta.forms.store.memento.ComponentMemento">
+         <at name="cellconstraints">
+          <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+           <at name="column">3</at>
+           <at name="row">4</at>
+           <at name="colspan">1</at>
+           <at name="rowspan">1</at>
+           <at name="halign">default</at>
+           <at name="valign">default</at>
+           <at name="insets" object="insets">0,0,0,0</at>
+          </object>
+         </at>
+         <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
+        </super>
+        <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
+        <at name="beanclass">javax.swing.JPanel</at>
+        <at name="beanproperties">
+         <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+          <at name="classname">javax.swing.JPanel</at>
+          <at name="properties">
+           <object classname="com.jeta.forms.store.support.PropertyMap">
+            <at name="name">defaultColorPanel</at>
+            <at name="width">12</at>
+            <at name="height">12</at>
+           </object>
+          </at>
+         </object>
+        </at>
+       </object>
+      </at>
+     </item>
+    </object>
+   </at>
+   <at name="properties">
+    <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+     <at name="classname">com.jeta.forms.gui.form.GridView</at>
+     <at name="properties">
+      <object classname="com.jeta.forms.store.support.PropertyMap">
+       <at name="border">
+        <object classname="com.jeta.forms.store.properties.CompoundBorderProperty">
+         <super classname="com.jeta.forms.store.properties.BorderProperty">
+          <at name="name">border</at>
+         </super>
+         <at name="borders">
+          <object classname="java.util.LinkedList"/>
+         </at>
+        </object>
+       </at>
+       <at name="name"/>
+       <at name="fill">
+        <object classname="com.jeta.forms.store.properties.effects.PaintProperty">
+         <at name="name">fill</at>
+        </object>
+       </at>
+       <at name="scollBars">
+        <object classname="com.jeta.forms.store.properties.ScrollBarsProperty">
+         <at name="name">scollBars</at>
+         <at name="verticalpolicy">21</at>
+         <at name="horizontalpolicy">31</at>
+         <at name="border">
+          <object classname="com.jeta.forms.store.properties.CompoundBorderProperty">
+           <super classname="com.jeta.forms.store.properties.BorderProperty">
+            <at name="name">border</at>
+           </super>
+           <at name="borders">
+            <object classname="java.util.LinkedList">
+             <item >
+              <at name="value">
+               <object classname="com.jeta.forms.store.properties.DefaultBorderProperty">
+                <super classname="com.jeta.forms.store.properties.BorderProperty">
+                 <at name="name">border</at>
+                </super>
+               </object>
+              </at>
+             </item>
+            </object>
+           </at>
+          </object>
+         </at>
+        </object>
+       </at>
+      </object>
+     </at>
+    </object>
+   </at>
+   <at name="cellpainters">
+    <object classname="com.jeta.forms.store.support.Matrix">
+     <at name="rows">
+      <object classname="[Ljava.lang.Object;" size="7">
+       <at name="item" index="0">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
+       <at name="item" index="1">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
+       <at name="item" index="2">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
+       <at name="item" index="3">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
+       <at name="item" index="4">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
+       <at name="item" index="5">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
+       <at name="item" index="6">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
+      </object>
+     </at>
+    </object>
+   </at>
+   <at name="rowgroups">
+    <object classname="com.jeta.forms.store.memento.FormGroupSet">
+     <at name="groups">
+      <object classname="java.util.HashMap"/>
+     </at>
+    </object>
+   </at>
+   <at name="colgroups">
+    <object classname="com.jeta.forms.store.memento.FormGroupSet">
+     <at name="groups">
+      <object classname="java.util.HashMap"/>
+     </at>
+    </object>
+   </at>
+  </object>
+ </at>
+</object>
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersView.xml
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersView.xml	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersView.xml	(revision 760)
@@ -25,8 +25,8 @@
     <at name="componentclass">com.jeta.forms.gui.form.FormComponent</at>
    </super>
    <at name="id">/home/lmarques/projects/externals/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersView.xml</at>
-   <at name="rowspecs">CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE</at>
-   <at name="colspecs">FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:GROW(1.0)</at>
+   <at name="rowspecs">CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE</at>
+   <at name="colspecs">FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:GROW(1.0)</at>
    <at name="components">
     <object classname="java.util.LinkedList">
      <item >
@@ -74,7 +74,7 @@
              </object>
             </at>
             <at name="name">elevationModeText</at>
-            <at name="width">90</at>
+            <at name="width">114</at>
             <at name="text">elevation_mode</at>
             <at name="fill">
              <object classname="com.jeta.forms.store.properties.effects.PaintProperty">
@@ -134,7 +134,7 @@
              </object>
             </at>
             <at name="name">defaultColorText</at>
-            <at name="width">90</at>
+            <at name="width">114</at>
             <at name="text">default_color</at>
             <at name="fill">
              <object classname="com.jeta.forms.store.properties.effects.PaintProperty">
@@ -193,8 +193,68 @@
               </at>
              </object>
             </at>
+            <at name="name">heightFieldText</at>
+            <at name="width">114</at>
+            <at name="text">height_field</at>
+            <at name="fill">
+             <object classname="com.jeta.forms.store.properties.effects.PaintProperty">
+              <at name="name">fill</at>
+             </object>
+            </at>
+            <at name="height">14</at>
+           </object>
+          </at>
+         </object>
+        </at>
+       </object>
+      </at>
+     </item>
+     <item >
+      <at name="value">
+       <object classname="com.jeta.forms.store.memento.BeanMemento">
+        <super classname="com.jeta.forms.store.memento.ComponentMemento">
+         <at name="cellconstraints">
+          <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+           <at name="column">1</at>
+           <at name="row">8</at>
+           <at name="colspan">1</at>
+           <at name="rowspan">1</at>
+           <at name="halign">default</at>
+           <at name="valign">default</at>
+           <at name="insets" object="insets">0,0,0,0</at>
+          </object>
+         </at>
+         <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
+        </super>
+        <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
+        <at name="beanclass">com.jeta.forms.components.label.JETALabel</at>
+        <at name="beanproperties">
+         <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+          <at name="classname">com.jeta.forms.components.label.JETALabel</at>
+          <at name="properties">
+           <object classname="com.jeta.forms.store.support.PropertyMap">
+            <at name="border">
+             <object classname="com.jeta.forms.store.properties.CompoundBorderProperty">
+              <super classname="com.jeta.forms.store.properties.BorderProperty">
+               <at name="name">border</at>
+              </super>
+              <at name="borders">
+               <object classname="java.util.LinkedList">
+                <item >
+                 <at name="value">
+                  <object classname="com.jeta.forms.store.properties.DefaultBorderProperty">
+                   <super classname="com.jeta.forms.store.properties.BorderProperty">
+                    <at name="name">border</at>
+                   </super>
+                  </object>
+                 </at>
+                </item>
+               </object>
+              </at>
+             </object>
+            </at>
             <at name="name">constantHeightText</at>
-            <at name="width">90</at>
+            <at name="width">114</at>
             <at name="text">constant_height</at>
             <at name="fill">
              <object classname="com.jeta.forms.store.properties.effects.PaintProperty">
@@ -215,8 +275,8 @@
         <super classname="com.jeta.forms.store.memento.ComponentMemento">
          <at name="cellconstraints">
           <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
-           <at name="column">3</at>
-           <at name="row">2</at>
+           <at name="column">1</at>
+           <at name="row">10</at>
            <at name="colspan">1</at>
            <at name="rowspan">1</at>
            <at name="halign">default</at>
@@ -227,6 +287,66 @@
          <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
         </super>
         <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
+        <at name="beanclass">com.jeta.forms.components.label.JETALabel</at>
+        <at name="beanproperties">
+         <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+          <at name="classname">com.jeta.forms.components.label.JETALabel</at>
+          <at name="properties">
+           <object classname="com.jeta.forms.store.support.PropertyMap">
+            <at name="border">
+             <object classname="com.jeta.forms.store.properties.CompoundBorderProperty">
+              <super classname="com.jeta.forms.store.properties.BorderProperty">
+               <at name="name">border</at>
+              </super>
+              <at name="borders">
+               <object classname="java.util.LinkedList">
+                <item >
+                 <at name="value">
+                  <object classname="com.jeta.forms.store.properties.DefaultBorderProperty">
+                   <super classname="com.jeta.forms.store.properties.BorderProperty">
+                    <at name="name">border</at>
+                   </super>
+                  </object>
+                 </at>
+                </item>
+               </object>
+              </at>
+             </object>
+            </at>
+            <at name="name">verticalExaggerationText</at>
+            <at name="width">114</at>
+            <at name="text">vertical_exaggeration</at>
+            <at name="fill">
+             <object classname="com.jeta.forms.store.properties.effects.PaintProperty">
+              <at name="name">fill</at>
+             </object>
+            </at>
+            <at name="height">14</at>
+           </object>
+          </at>
+         </object>
+        </at>
+       </object>
+      </at>
+     </item>
+     <item >
+      <at name="value">
+       <object classname="com.jeta.forms.store.memento.BeanMemento">
+        <super classname="com.jeta.forms.store.memento.ComponentMemento">
+         <at name="cellconstraints">
+          <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+           <at name="column">3</at>
+           <at name="row">6</at>
+           <at name="colspan">2</at>
+           <at name="rowspan">1</at>
+           <at name="halign">default</at>
+           <at name="valign">default</at>
+           <at name="insets" object="insets">0,0,0,0</at>
+          </object>
+         </at>
+         <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
+        </super>
+        <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
         <at name="beanclass">javax.swing.JComboBox</at>
         <at name="beanproperties">
          <object classname="com.jeta.forms.store.memento.PropertiesMemento">
@@ -253,8 +373,8 @@
               </at>
              </object>
             </at>
-            <at name="name">elevationMode</at>
-            <at name="width">1408</at>
+            <at name="name">heightField</at>
+            <at name="width">790</at>
             <at name="items">
              <object classname="com.jeta.forms.store.properties.ItemsProperty">
               <at name="name">items</at>
@@ -275,8 +395,8 @@
          <at name="cellconstraints">
           <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
            <at name="column">3</at>
-           <at name="row">4</at>
-           <at name="colspan">1</at>
+           <at name="row">8</at>
+           <at name="colspan">2</at>
            <at name="rowspan">1</at>
            <at name="halign">default</at>
            <at name="valign">default</at>
@@ -286,10 +406,10 @@
          <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
         </super>
         <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
-        <at name="beanclass">javax.swing.JButton</at>
+        <at name="beanclass">javax.swing.JTextField</at>
         <at name="beanproperties">
          <object classname="com.jeta.forms.store.memento.PropertiesMemento">
-          <at name="classname">javax.swing.JButton</at>
+          <at name="classname">javax.swing.JTextField</at>
           <at name="properties">
            <object classname="com.jeta.forms.store.support.PropertyMap">
             <at name="border">
@@ -312,11 +432,9 @@
               </at>
              </object>
             </at>
-            <at name="actionCommand">...</at>
-            <at name="name">defaultColor</at>
-            <at name="width">1408</at>
-            <at name="text">...</at>
-            <at name="height">22</at>
+            <at name="name">constantHeight</at>
+            <at name="width">790</at>
+            <at name="height">20</at>
            </object>
           </at>
          </object>
@@ -331,8 +449,8 @@
          <at name="cellconstraints">
           <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
            <at name="column">3</at>
-           <at name="row">6</at>
-           <at name="colspan">1</at>
+           <at name="row">10</at>
+           <at name="colspan">2</at>
            <at name="rowspan">1</at>
            <at name="halign">default</at>
            <at name="valign">default</at>
@@ -368,8 +486,8 @@
               </at>
              </object>
             </at>
-            <at name="name">constantHeight</at>
-            <at name="width">1408</at>
+            <at name="name">verticalExaggeration</at>
+            <at name="width">790</at>
             <at name="height">20</at>
            </object>
           </at>
@@ -378,6 +496,99 @@
        </object>
       </at>
      </item>
+     <item >
+      <at name="value">
+       <object classname="com.jeta.forms.store.memento.BeanMemento">
+        <super classname="com.jeta.forms.store.memento.ComponentMemento">
+         <at name="cellconstraints">
+          <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+           <at name="column">3</at>
+           <at name="row">2</at>
+           <at name="colspan">2</at>
+           <at name="rowspan">1</at>
+           <at name="halign">default</at>
+           <at name="valign">default</at>
+           <at name="insets" object="insets">0,0,0,0</at>
+          </object>
+         </at>
+         <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
+        </super>
+        <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
+        <at name="beanclass">javax.swing.JComboBox</at>
+        <at name="beanproperties">
+         <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+          <at name="classname">javax.swing.JComboBox</at>
+          <at name="properties">
+           <object classname="com.jeta.forms.store.support.PropertyMap">
+            <at name="border">
+             <object classname="com.jeta.forms.store.properties.CompoundBorderProperty">
+              <super classname="com.jeta.forms.store.properties.BorderProperty">
+               <at name="name">border</at>
+              </super>
+              <at name="borders">
+               <object classname="java.util.LinkedList">
+                <item >
+                 <at name="value">
+                  <object classname="com.jeta.forms.store.properties.DefaultBorderProperty">
+                   <super classname="com.jeta.forms.store.properties.BorderProperty">
+                    <at name="name">border</at>
+                   </super>
+                  </object>
+                 </at>
+                </item>
+               </object>
+              </at>
+             </object>
+            </at>
+            <at name="name">elevationMode</at>
+            <at name="width">790</at>
+            <at name="items">
+             <object classname="com.jeta.forms.store.properties.ItemsProperty">
+              <at name="name">items</at>
+             </object>
+            </at>
+            <at name="height">20</at>
+           </object>
+          </at>
+         </object>
+        </at>
+       </object>
+      </at>
+     </item>
+     <item >
+      <at name="value">
+       <object classname="com.jeta.forms.store.memento.BeanMemento">
+        <super classname="com.jeta.forms.store.memento.ComponentMemento">
+         <at name="cellconstraints">
+          <object classname="com.jeta.forms.store.memento.CellConstraintsMemento">
+           <at name="column">3</at>
+           <at name="row">4</at>
+           <at name="colspan">1</at>
+           <at name="rowspan">1</at>
+           <at name="halign">default</at>
+           <at name="valign">default</at>
+           <at name="insets" object="insets">0,0,0,0</at>
+          </object>
+         </at>
+         <at name="componentclass">com.jeta.forms.gui.form.StandardComponent</at>
+        </super>
+        <at name="jetabeanclass">com.jeta.forms.gui.beans.JETABean</at>
+        <at name="beanclass">javax.swing.JPanel</at>
+        <at name="beanproperties">
+         <object classname="com.jeta.forms.store.memento.PropertiesMemento">
+          <at name="classname">javax.swing.JPanel</at>
+          <at name="properties">
+           <object classname="com.jeta.forms.store.support.PropertyMap">
+            <at name="name">defaultColorPanel</at>
+            <at name="width">12</at>
+            <at name="height">12</at>
+           </object>
+          </at>
+         </object>
+        </at>
+       </object>
+      </at>
+     </item>
     </object>
    </at>
    <at name="properties">
@@ -395,7 +606,7 @@
          </at>
         </object>
        </at>
-       <at name="name"></at>
+       <at name="name"/>
        <at name="fill">
         <object classname="com.jeta.forms.store.properties.effects.PaintProperty">
          <at name="name">fill</at>
@@ -435,28 +646,40 @@
    <at name="cellpainters">
     <object classname="com.jeta.forms.store.support.Matrix">
      <at name="rows">
-      <object classname="[Ljava.lang.Object;" size="7">
+      <object classname="[Ljava.lang.Object;" size="11">
        <at name="item" index="0">
-        <object classname="[Ljava.lang.Object;" size="3"/>
+        <object classname="[Ljava.lang.Object;" size="4"/>
        </at>
        <at name="item" index="1">
-        <object classname="[Ljava.lang.Object;" size="3"/>
+        <object classname="[Ljava.lang.Object;" size="4"/>
        </at>
        <at name="item" index="2">
-        <object classname="[Ljava.lang.Object;" size="3"/>
+        <object classname="[Ljava.lang.Object;" size="4"/>
        </at>
        <at name="item" index="3">
-        <object classname="[Ljava.lang.Object;" size="3"/>
+        <object classname="[Ljava.lang.Object;" size="4"/>
        </at>
        <at name="item" index="4">
-        <object classname="[Ljava.lang.Object;" size="3"/>
+        <object classname="[Ljava.lang.Object;" size="4"/>
        </at>
        <at name="item" index="5">
-        <object classname="[Ljava.lang.Object;" size="3"/>
+        <object classname="[Ljava.lang.Object;" size="4"/>
        </at>
        <at name="item" index="6">
-        <object classname="[Ljava.lang.Object;" size="3"/>
+        <object classname="[Ljava.lang.Object;" size="4"/>
        </at>
+       <at name="item" index="7">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
+       <at name="item" index="8">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
+       <at name="item" index="9">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
+       <at name="item" index="10">
+        <object classname="[Ljava.lang.Object;" size="4"/>
+       </at>
       </object>
      </at>
     </object>
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersView.java
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersView.java	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorLoaderParametersView.java	(revision 760)
@@ -8,7 +8,6 @@
 import java.awt.Dimension;
 import javax.swing.Box;
 import javax.swing.ImageIcon;
-import javax.swing.JButton;
 import javax.swing.JComboBox;
 import javax.swing.JFrame;
 import javax.swing.JLabel;
@@ -22,8 +21,8 @@
    JLabel defaultColorText = new JLabel();
    JLabel constantHeightText = new JLabel();
    JComboBox elevationMode = new JComboBox();
-   JButton defaultColor = new JButton();
    JTextField constantHeight = new JTextField();
+   JPanel defaultColorPanel = new JPanel();
 
    /**
     * Default constructor
@@ -115,7 +114,7 @@
    public JPanel createPanel()
    {
       JPanel jpanel1 = new JPanel();
-      FormLayout formlayout1 = new FormLayout("FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:GROW(1.0)","CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE");
+      FormLayout formlayout1 = new FormLayout("FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:GROW(1.0)","CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE");
       CellConstraints cc = new CellConstraints();
       jpanel1.setLayout(formlayout1);
 
@@ -132,17 +131,15 @@
       jpanel1.add(constantHeightText,cc.xy(1,6));
 
       elevationMode.setName("elevationMode");
-      jpanel1.add(elevationMode,cc.xy(3,2));
+      jpanel1.add(elevationMode,cc.xywh(3,2,2,1));
 
-      defaultColor.setActionCommand("...");
-      defaultColor.setName("defaultColor");
-      defaultColor.setText("...");
-      jpanel1.add(defaultColor,cc.xy(3,4));
-
       constantHeight.setName("constantHeight");
-      jpanel1.add(constantHeight,cc.xy(3,6));
+      jpanel1.add(constantHeight,cc.xywh(3,6,2,1));
 
-      addFillComponents(jpanel1,new int[]{ 1,2,3 },new int[]{ 1,3,5,7 });
+      defaultColorPanel.setName("defaultColorPanel");
+      jpanel1.add(defaultColorPanel,cc.xy(3,4));
+
+      addFillComponents(jpanel1,new int[]{ 1,2,3,4 },new int[]{ 1,3,5,7 });
       return jpanel1;
    }
 
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersView.java
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersView.java	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JVectorExtrusionLoaderParametersView.java	(revision 760)
@@ -8,7 +8,6 @@
 import java.awt.Dimension;
 import javax.swing.Box;
 import javax.swing.ImageIcon;
-import javax.swing.JButton;
 import javax.swing.JComboBox;
 import javax.swing.JFrame;
 import javax.swing.JLabel;
@@ -20,10 +19,14 @@
 {
    JLabel elevationModeText = new JLabel();
    JLabel defaultColorText = new JLabel();
+   JLabel heightFieldText = new JLabel();
    JLabel constantHeightText = new JLabel();
+   JLabel verticalExaggerationText = new JLabel();
+   JComboBox heightField = new JComboBox();
+   JTextField constantHeight = new JTextField();
+   JTextField verticalExaggeration = new JTextField();
    JComboBox elevationMode = new JComboBox();
-   JButton defaultColor = new JButton();
-   JTextField constantHeight = new JTextField();
+   JPanel defaultColorPanel = new JPanel();
 
    /**
     * Default constructor
@@ -115,7 +118,7 @@
    public JPanel createPanel()
    {
       JPanel jpanel1 = new JPanel();
-      FormLayout formlayout1 = new FormLayout("FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:GROW(1.0)","CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE");
+      FormLayout formlayout1 = new FormLayout("FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:NONE,FILL:DEFAULT:GROW(1.0)","CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE,CENTER:DEFAULT:NONE,CENTER:4DLU:NONE");
       CellConstraints cc = new CellConstraints();
       jpanel1.setLayout(formlayout1);
 
@@ -127,22 +130,34 @@
       defaultColorText.setText("default_color");
       jpanel1.add(defaultColorText,cc.xy(1,4));
 
+      heightFieldText.setName("heightFieldText");
+      heightFieldText.setText("height_field");
+      jpanel1.add(heightFieldText,cc.xy(1,6));
+
       constantHeightText.setName("constantHeightText");
       constantHeightText.setText("constant_height");
-      jpanel1.add(constantHeightText,cc.xy(1,6));
+      jpanel1.add(constantHeightText,cc.xy(1,8));
 
-      elevationMode.setName("elevationMode");
-      jpanel1.add(elevationMode,cc.xy(3,2));
+      verticalExaggerationText.setName("verticalExaggerationText");
+      verticalExaggerationText.setText("vertical_exaggeration");
+      jpanel1.add(verticalExaggerationText,cc.xy(1,10));
 
-      defaultColor.setActionCommand("...");
-      defaultColor.setName("defaultColor");
-      defaultColor.setText("...");
-      jpanel1.add(defaultColor,cc.xy(3,4));
+      heightField.setName("heightField");
+      jpanel1.add(heightField,cc.xywh(3,6,2,1));
 
       constantHeight.setName("constantHeight");
-      jpanel1.add(constantHeight,cc.xy(3,6));
+      jpanel1.add(constantHeight,cc.xywh(3,8,2,1));
 
-      addFillComponents(jpanel1,new int[]{ 1,2,3 },new int[]{ 1,3,5,7 });
+      verticalExaggeration.setName("verticalExaggeration");
+      jpanel1.add(verticalExaggeration,cc.xywh(3,10,2,1));
+
+      elevationMode.setName("elevationMode");
+      jpanel1.add(elevationMode,cc.xywh(3,2,2,1));
+
+      defaultColorPanel.setName("defaultColorPanel");
+      jpanel1.add(defaultColorPanel,cc.xy(3,4));
+
+      addFillComponents(jpanel1,new int[]{ 1,2,3,4 },new int[]{ 1,3,5,7,9,11 });
       return jpanel1;
    }
 
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JColorChooserButton.java
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JColorChooserButton.java	(revision 0)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.swing/org.gvsig.view3d.vector.swing.impl/src/main/java/org/gvsig/view3d/vector/swing/impl/JColorChooserButton.java	(revision 760)
@@ -0,0 +1,115 @@
+/**
+ * gvSIG. Desktop Geographic Information System.
+ *
+ * Copyright © 2007-2016 gvSIG Association
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA  02110-1301, USA.
+ *
+ * For any additional information, do not hesitate to contact us
+ * at info AT gvsig.com, or visit our website www.gvsig.com.
+ */
+package org.gvsig.view3d.vector.swing.impl;
+
+import java.awt.Color;
+import java.awt.Graphics2D;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.image.BufferedImage;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Random;
+
+import javax.swing.ImageIcon;
+import javax.swing.JButton;
+import javax.swing.JColorChooser;
+
+import org.gvsig.tools.ToolsLocator;
+import org.gvsig.tools.i18n.I18nManager;
+
+/**
+ * Button for color selection.
+ * 
+ * <p>As off: http://stackoverflow.com/questions/26565166/how-to-display-a-color-selector-when-clicking-a-button
+ * 
+ */
+public class JColorChooserButton extends JButton {
+    private I18nManager i18nManager = ToolsLocator.getI18nManager();
+    private Color current;
+
+    public JColorChooserButton( Color c ) {
+        setSelectedColor(c);
+        addActionListener(new ActionListener(){
+            @Override
+            public void actionPerformed( ActionEvent arg0 ) {
+                Color newColor = JColorChooser.showDialog(null, i18nManager.getTranslation("Choose a Color"), current);
+                setSelectedColor(newColor);
+            }
+        });
+    }
+
+    public Color getSelectedColor() {
+        return current;
+    }
+
+    public void setSelectedColor( Color newColor ) {
+        setSelectedColor(newColor, true);
+    }
+
+    public void setSelectedColor( Color newColor, boolean notify ) {
+
+        if (newColor == null) {
+            Random rand = new Random();
+            float r = rand.nextFloat();
+            float g = rand.nextFloat();
+            float b = rand.nextFloat();
+            this.current = new Color(r, g, b);
+        } else {
+            this.current = newColor;
+        }
+        
+        setIcon(createIcon(current, 16, 16));
+        repaint();
+
+        if (notify) {
+            // Notify everybody that may be interested.
+            for( ColorChangedListener l : listeners ) {
+                l.colorChanged(newColor);
+            }
+        }
+    }
+
+    public static interface ColorChangedListener {
+        public void colorChanged( Color newColor );
+    }
+
+    private List<ColorChangedListener> listeners = new ArrayList<ColorChangedListener>();
+
+    public void addColorChangedListener( ColorChangedListener toAdd ) {
+        listeners.add(toAdd);
+    }
+
+    public static ImageIcon createIcon( Color main, int width, int height ) {
+        BufferedImage image = new BufferedImage(width, height, java.awt.image.BufferedImage.TYPE_INT_RGB);
+        Graphics2D graphics = image.createGraphics();
+        graphics.setColor(main);
+        graphics.fillRect(0, 0, width, height);
+        graphics.setXORMode(Color.DARK_GRAY);
+        graphics.drawRect(0, 0, width - 1, height - 1);
+        image.flush();
+        ImageIcon icon = new ImageIcon(image);
+        return icon;
+    }
+}
\ No newline at end of file
Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.lib/org.gvsig.view3d.vector.lib.impl/src/main/java/org/gvsig/view3d/vector/lib/impl/DefaultVectorExtrusionLoaderParameters.java
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.lib/org.gvsig.view3d.vector.lib.impl/src/main/java/org/gvsig/view3d/vector/lib/impl/DefaultVectorExtrusionLoaderParameters.java	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.lib/org.gvsig.view3d.vector.lib.impl/src/main/java/org/gvsig/view3d/vector/lib/impl/DefaultVectorExtrusionLoaderParameters.java	(revision 760)
@@ -25,7 +25,7 @@
     public static final String PARAMETERS_DEFINITION_DESCRIPTION =
         "Parameters that defines vector extrusion load mode";
 
-    public static final String VECTOR_ELEVATION_MODEL_FIELD_NAME = "vectorElevationModel";
+    public static final String VECTOR_ELEVATION_MODE_FIELD_NAME = "vectorElevationMode";
     public static final String DEFAULT_COLOR_FIELD_NAME = "defaultColor";
     public static final String HEIGHT_FIELD_FIELD_NAME = "heightField";
     public static final String CONSTANT_HEIGHT_FIELD_NAME = "constantHeight";
@@ -47,12 +47,12 @@
     }
 
     @Override
-    public VectorElevationMode getVectorElevationModel() {
+    public VectorElevationMode getVectorElevationMode() {
         return this.vectorElevationMode;
     }
 
     @Override
-    public void setVectorElevationModel(VectorElevationMode vectorElevationMode) {
+    public void setVectorElevationMode(VectorElevationMode vectorElevationMode) {
         this.vectorElevationMode = vectorElevationMode;
     }
 
@@ -87,13 +87,13 @@
     }
 
     @Override
-    public double getVerticalExageration() {
+    public double getVerticalExaggeration() {
         return this.verticalExaggeration;
     }
 
     @Override
-    public void setVerticalExageration(double verticalExageration) {
-        this.verticalExaggeration = verticalExageration;
+    public void setVerticalExaggeration(double verticalExaggeration) {
+        this.verticalExaggeration = verticalExaggeration;
     }
     
     public static void registerPersistenceDefinition() {
@@ -103,7 +103,7 @@
             definition = manager.addDefinition(DefaultVectorLoaderParameters.class, PARAMETERS_DEFINITION_NAME,
                 PARAMETERS_DEFINITION_DESCRIPTION, null, null);
 
-            definition.addDynFieldObject(VECTOR_ELEVATION_MODEL_FIELD_NAME);
+            definition.addDynFieldObject(VECTOR_ELEVATION_MODE_FIELD_NAME);
             definition.addDynFieldObject(DEFAULT_COLOR_FIELD_NAME);
             definition.addDynFieldString(HEIGHT_FIELD_FIELD_NAME);
             definition.addDynFieldDouble(CONSTANT_HEIGHT_FIELD_NAME);
@@ -115,7 +115,7 @@
     public Object clone() throws CloneNotSupportedException {
 
         VectorLoaderParameters newParameters = new DefaultVectorLoaderParameters();
-        newParameters.setVectorElevationMode(this.getVectorElevationModel());
+        newParameters.setVectorElevationMode(this.getVectorElevationMode());
         newParameters.setDefaultColor(this.getDefaultColor());
         newParameters.setConstantHeight(this.getConstantHeight());
         newParameters.setLayer(this.getLayer());
@@ -124,14 +124,19 @@
 
     @Override
     protected void doSaveToState(PersistentState state) throws PersistenceException {
-        state.set(VECTOR_ELEVATION_MODEL_FIELD_NAME, this.vectorElevationMode);
+        state.set(VECTOR_ELEVATION_MODE_FIELD_NAME, this.vectorElevationMode);
         state.set(DEFAULT_COLOR_FIELD_NAME, this.defaultColor);
+        state.set(HEIGHT_FIELD_FIELD_NAME, this.heightField);
         state.set(CONSTANT_HEIGHT_FIELD_NAME, this.constantHeight);
+        state.set(VERTICAL_EXAGGERATION_FIELD_NAME, this.verticalExaggeration);
     }
 
     @Override
     protected void doLoadFromState(PersistentState state) throws PersistenceException {
-        // TODO Auto-generated method stub
-
+        this.vectorElevationMode = (VectorElevationMode) state.get(VECTOR_ELEVATION_MODE_FIELD_NAME);
+        this.defaultColor = (Color) state.get(DEFAULT_COLOR_FIELD_NAME);
+        this.heightField = state.getString(HEIGHT_FIELD_FIELD_NAME);
+        this.constantHeight = state.getDouble(CONSTANT_HEIGHT_FIELD_NAME);
+        this.verticalExaggeration = state.getDouble(VERTICAL_EXAGGERATION_FIELD_NAME);
     }
 }

Index: 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.lib/org.gvsig.view3d.vector.lib.api/src/main/java/org/gvsig/view3d/vector/lib/api/VectorExtrusionLoaderParameters.java
===================================================================
--- 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.lib/org.gvsig.view3d.vector.lib.api/src/main/java/org/gvsig/view3d/vector/lib/api/VectorExtrusionLoaderParameters.java	(revision 759)
+++ 2.1/trunk/org.gvsig.view3d/org.gvsig.view3d.vector/org.gvsig.view3d.vector.lib/org.gvsig.view3d.vector.lib.api/src/main/java/org/gvsig/view3d/vector/lib/api/VectorExtrusionLoaderParameters.java	(revision 760)
@@ -20,7 +20,7 @@
      * 
      * @return
      */
-    public VectorElevationMode getVectorElevationModel();
+    public VectorElevationMode getVectorElevationMode();
 
     /**
      * Sets the specific {@link VectorElevationMode} to this vector layer
@@ -29,7 +29,7 @@
      * @param vectorElevationMode
      *            the specific {@link VectorElevationMode}
      */
-    public void setVectorElevationModel(VectorElevationMode vectorElevationMode);
+    public void setVectorElevationMode(VectorElevationMode vectorElevationMode);
 
     /**
      * Gets default {@link Color} of vector layer properties. Default color is
@@ -79,16 +79,16 @@
     public void setConstantHeight(double height);
 
     /**
      * Gets vertical exageration
      * 
      * @return
      */
-    public double getVerticalExageration();
+    public double getVerticalExaggeration();
 
     /**
      * Sets the specific vertical exageration to this properties
      * 
-     * @param verticalExageration
+     * @param verticalExaggeration
      */
-    public void setVerticalExageration(double verticalExageration);
+    public void setVerticalExaggeration(double verticalExaggeration);
 }
@@ -79,16 +79,16 @@
 
     /**
-     * Gets vertical exageration
+     * Gets vertical exaggeration
      * 
      * @return
@@ -79,16 +79,16 @@
 
     /**
-     * Sets the specific vertical exageration to this properties
+     * Sets the specific vertical exaggeration to this properties
      * 